@@ -1,5 +1,5 @@
 /* libunwind - a platform-independent unwind library
-   Copyright (C) 2003 Hewlett-Packard Co
+   Copyright (C) 2003-2004 Hewlett-Packard Co
 	Contributed by David Mosberger-Tang <davidm@hpl.hp.com>
 
 This file is part of libunwind.
@@ -32,12 +32,7 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.  */
 #include "tdep.h"
 #include "os-linux.h"
 
-/* Here, it doesn't matter whether we include elf64.h or elf32.h.
-   Both define "struct elf_image" and elf_map_image() in an identical
-   fashion.  */
-#include "elf64.h"
-
-HIDDEN int
+PROTECTED int
 tdep_get_elf_image (struct elf_image *ei, pid_t pid, unw_word_t ip,
 		    unsigned long *segbase, unsigned long *mapoff)
 {
@@ -47,7 +42,7 @@ tdep_get_elf_image (struct elf_image *ei, pid_t pid, unw_word_t ip,
   unsigned long hi;
 
   maps_init (&mi, pid);
-  while (maps_next (&mi, segbase, &hi, mapoff, path))
+  while (maps_next (&mi, segbase, &hi, mapoff, path, sizeof (path)))
     if (ip >= *segbase && ip < hi)
       {
 	found = 1;
